<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr" sourcelanguage="en_US">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="363"/>
        <source>Learn Basic Operations</source>
        <translation>Научи Основне Операције</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="366"/>
        <source>Common Application Libraries</source>
        <translation>Честе Библиотеке Програма</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="369"/>
        <source>Desktop Environment</source>
        <translation>Радно окружење</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
        <source>Search for "%1" in the full text</source>
        <translation>Тражи "%1" у целом тексту</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="363"/>
        <source>The content was updated</source>
        <translation>Садржај је ажуриран</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="767"/>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
        <source>Support</source>
        <translation>Подршка</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="1038"/>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>Quick Start</source>
        <translation>Брзи Покрет</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
        <source>Video Guide</source>
        <translation>Видео Гуд</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
        <source>System</source>
        <translation>Систем</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>Applications</source>
        <translation>Програми</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
        <source>No search results</source>
        <translation>Нема резултата претраге</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>Home</source>
        <translation>Почетак</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>  result</source>
        <translation>  резултат</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
        <source>  results</source>
        <translation>  резултата</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
        <source>Click to view </source>
        <translation>Кликни за приказ </translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
        <source>View all</source>
        <translation>Прикажи све</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
        <source>App Store</source>
        <translation>Магацин Програма</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="136"/>
        <source>Manual</source>
        <translation>Приручник</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="137"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>Приручник је састављен тако да помогне корисницима да изуче оперативни систем и програме, нудећи усмерена упутства и описе функција.</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="952"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="969"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>
